pascual » Quick-and-dirty guide

IMPORTANT: These instructions are quite outdated. From version 1.2, a wizard (assistant) makes the setting of parameters much easier. Also most (if not all) the information in this mini-guide is already covered in the Manual.
So... READ THE USER MANUAL INSTEAD!!
Here are some instructions I wrote in an email. I will polish this, but for the moment it may help:
To use PAScual in graphic mode (recommended), launch PAScualGUI.py
Regarding to the use. I will put this in the manual ASAP, but here are a few tips:
First of all: use the "?" button: by clicking it and then on some elements of the window, you may get useful tips.
Here is a step-by-step guide to analyse a spectrum (or a set of them) with the GUI interface:
1.-Launch PAScualGUI.py. You should get the main window of the program.
2.-Load the spectra (File-->Load spectra). You will see them appearing in the "spectra selection" pane on the left. You can select or unselect them using the green square to the left of the name. The parameters will only be set for the spectra that are selected.
3.-Set the Region of interest for the fit (you will be prompted when loading). You can type the min and max channels manually or click on the box and then on the graph. If you are using the example data, you can leave it from 0 to 1024.
4.-fill the initial guesses for the parameters. Each parameter has a green check icon on its right. Click on it after changing the number to apply this value to every selected spectra.
The CPI_A_xxx.dat series is a series of artificially generated spectra. The values used for generating them are:
For the CPI_A_xxx.dat spectra you can use the following:
channel width: 50ps
FWHM: 270
Background: 100 (you can either type it manually or use the calculator button on its left to estimate the initial guess from the spectrum)
offset: 20 (you can either type it manually or use the calculator button on its left to calculate the initial guess from the spectrum)
3 components: (I am not totally sure about some values righ now, but you can put anything )
lifetimes 125, 400, ~2000 ps
intensities: 15, 20, 65 % (but you don't really need to give any initial guess for intensities, just leave the defaults)
5.- Make sure you have applied all the parameters. You can see this by looking at the table in the "spectra selection" pane. Everything should be green for the selected spectra (including the name). Note that there is an "Apply all" button on the right bottom corner. If you click on it, the current parameters will be applied to every selected spectrum (it is like clicking all the "apply parameters" together).
6.- Now you can go to the "Fitting" tab. On the right you see two panes, one containing "Commands" and the other containing "Sets". In the "sets" You should see one set for each spectrum you loaded (each set containing one spectrum only). This is the case unless you chose a common parameter...
The command table shows the commands that will be executed for each set. You can change the commands manually or simply by choosing a predefined fitting mode from a dropdown list just above (by default, you will see "LOCAL-connected". LOCAL-Connected emulates the behaviour of LTv9. It means that the fit will use the faster LOCAL algorithm and that the results from the previous fit will be used for initialising the next fit.
7.-Just for the first test, you can leave things as they are and click on the "play" button at the bottom right of this tab. This should launch the fit. And you should see the progress bars running.
8.-If everything went ok, you should see the results in the "Results" tab. If the chi2 is in too bad values (maybe infinite), the row should be red.
9.-Doubleclicking on any cell of the table should show (at the bottom) the residuals of the fit for the spectrum represented in that row.
10.-The "Output tab" logs (in text mode) all the results. It is useful for troubleshooting. If you want to report problems, you may want to copy and paste the contents of this window.
Finally, about the different Fitting modes available: there are some predefined fitting modes. You can modify them or include your own. They are simply a set of commands to be run for each set of spectra.
The commands are:
SAVE: saves current value of the parameters (to be later read by LOAD)
LOAD: loads previous results saved with SAVE. If SAVE was not run, it does nothing.
LOCAL: Performs a local fit.
SA: Performs a simulated annealing fit (slower than local).
BI: Performs a Bayesian Inference run (even Slower)
Note: the behaviour of some of this algorithms can be altered editing the "AdvOpt.py" file, but you can mess things up if you don't know what you are doing.